@@ -12,26 +12,23 @@
 
    Copyright 2022, HSPyLib team
 """
-import re
-import time
-from typing import List, Optional
-
-import pyperclip
-from hspylib.core.exception.exceptions import InvalidInputError
-from hspylib.core.namespace import Namespace
-from hspylib.core.tools.commons import syserr, sysout
-from hspylib.modules.cli.vt100.vt_utils import (
-    get_cursor_position, prepare_render, restore_cursor, set_enable_echo,
-)
-
 from clitt.core.icons.font_awesome.form_icons import FormIcons
 from clitt.core.icons.font_awesome.nav_icons import NavIcons
-from clitt.core.keyboard import Keyboard
 from clitt.core.tui.minput.form_builder import FormBuilder
 from clitt.core.tui.minput.form_field import FormField
 from clitt.core.tui.minput.input_type import InputType
 from clitt.core.tui.minput.minput_utils import MInputUtils
 from clitt.core.tui.tui_component import TUIComponent
+from hspylib.core.exception.exceptions import InvalidInputError
+from hspylib.core.namespace import Namespace
+from hspylib.core.tools.commons import syserr, sysout
+from hspylib.modules.cli.keyboard import Keyboard
+from hspylib.modules.cli.vt100.vt_utils import get_cursor_position, prepare_render, restore_cursor, set_enable_echo
+from typing import List, Optional
+
+import pyperclip
+import re
+import time
 
 
 def minput(
